@@ -5,6 +5,7 @@ from gettext import gettext as _
 from os.path import exists, dirname
 from deskbar.defs import VERSION
 from deskbar.core.Utils import is_program_in_path, spawn_async, url_show, url_show_file
+import deskbar.interfaces.Action
 
 MAX_RESULTS = 20 # per handler
 HANDLERS = ["BeagleLiveHandler"]
@@ -103,39 +104,12 @@ TYPES = {
 for key, val in TYPES.items():
 	if "snippet" in val and val["snippet"]:
 		val["description"] += "%(snippet)s"
-		
-class BeagleLiveMatch (deskbar.interfaces.Match):
-	def __init__(self, result=None, **args):
-		"""
-		result: a dict containing:
-			"name" : a name sensible to display for this match
-			"uri": the uri of the match as provided by the beagled 'Uri: '-field
-			"type": One of the types listed in the TYPES dict
 
-		-- and optionally extra fields as provided by the corresponding entry in TYPES.
-		Fx. "MailMessage". has an extra "sender" entry.
-		"""
-		deskbar.interfaces.Match.__init__ (self, name=result["name"], **args)
+class OpenBeagleLiveAction(deskbar.interfaces.Action):
+	
+	def __init__(self, name, result):
+		deskbar.interfaces.Action.__init__(self, name)
 		self.result = result
-
-		# IM Log viewer take loca paths only		
-		action = TYPES[self.result["type"]]["action"]
-		if not callable(action) and action.startswith("beagle-imlogviewer"):
-			# Strip the uti descriptor, because imlogviewer takes a local path
-			self.result["uri"] = gnomevfs.get_local_path_from_uri(self.result["uri"])			
-		
-		# Load the correct icon
-		
-		#
-		# There is bug http://bugzilla.gnome.org/show_bug.cgi?id=319549
-		# which has been fixed and comitted, so we re-enable this snippet
-		#
-		
-		if result["type"] == "File":
-			try:
-				self.icon = result["uri"]
-			except Exception:
-				pass
 		
 	def get_name (self, text=None):
 		# We use the result dict itself to look up words
@@ -164,6 +138,41 @@ class BeagleLiveMatch (deskbar.interfaces.Match):
 
 			print "BeagleLive spawning:", action, args
 			spawn_async(args)
+		
+class BeagleLiveMatch (deskbar.interfaces.Match):
+	def __init__(self, result=None, **args):
+		"""
+		result: a dict containing:
+			"name" : a name sensible to display for this match
+			"uri": the uri of the match as provided by the beagled 'Uri: '-field
+			"type": One of the types listed in the TYPES dict
+
+		-- and optionally extra fields as provided by the corresponding entry in TYPES.
+		Fx. "MailMessage". has an extra "sender" entry.
+		"""
+		deskbar.interfaces.Match.__init__ (self, name=result["name"], **args)
+		self.result = result
+
+		# IM Log viewer take loca paths only		
+		action = TYPES[self.result["type"]]["action"]
+		if not callable(action) and action.startswith("beagle-imlogviewer"):
+			# Strip the uti descriptor, because imlogviewer takes a local path
+			self.result["uri"] = gnomevfs.get_local_path_from_uri(self.result["uri"])			
+		
+		self.add_action( OpenBeagleLiveAction(self.get_name(), self.result) )
+		
+		# Load the correct icon
+		
+		#
+		# There is bug http://bugzilla.gnome.org/show_bug.cgi?id=319549
+		# which has been fixed and comitted, so we re-enable this snippet
+		#
+		
+		if result["type"] == "File":
+			try:
+				self.icon = result["uri"]
+			except Exception:
+				pass
 	
 	def get_hash(self, text=None):
 		if "uri" in self.result:
@@ -371,7 +380,6 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
 			import beagle
 		except Exception, e:
 			BeagleLiveHandler.INSTRUCTIONS = _("Could not load beagle, libbeagle has been compiled without python bindings.")
-			print >> sys.stderr, str(e)
 			return False
 	
 		# Check if beagled is running		
