@@ -11,9 +11,10 @@ import deskbar.interfaces.Match
 from deskbar.defs import VERSION
 from deskbar.core.Watcher import FileWatcher
 from deskbar.core.Utils import spawn_async, url_show_file
+from deskbar.handlers.actions.OpenWithNautilusAction import OpenWithNautilusAction
+from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
+from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
 
-NETWORK_URIS = ["http", "ftp", "smb", "sftp"]
-AUDIO_URIS = ["cdda"]
 MONITOR = gnomevfs.VolumeMonitor()
 
 HANDLERS = ["FileFolderHandler"]
@@ -24,15 +25,8 @@ class FileMatch(deskbar.interfaces.Match):
 	def __init__(self, name=None, absname=None, **args):
 		deskbar.interfaces.Match.__init__(self, name=name, icon=absname, category="files", **args)
 		self.absname = absname
-				
-	def action(self, text=None):
-		url_show_file(self.absname)
-
-	def is_valid(self, text=None):
-		return exists(self.absname)
-
-	def get_verb(self):
-		return _("Open %s") % "<b>%(name)s</b>"
+		self.add_action( ShowUrlAction(name, absname) )
+		self.add_action( CopyToClipboardAction(_("Location"), absname) )
 	
 	def get_hash(self, text=None):
 		return self.absname
@@ -41,15 +35,8 @@ class FolderMatch(deskbar.interfaces.Match):
 	def __init__(self, name=None, absname=None, **args):
 		deskbar.interfaces.Match.__init__(self, name=name, icon=absname, category="places", **args)
 		self.absname = absname
-		
-	def action(self, text=None):
-		url_show_file(self.absname)
-	
-	def is_valid(self, text=None):
-		return exists(self.absname)
-	
-	def get_verb(self):
-		return _("Open folder %s") % "<b>%(name)s</b>"
+		self.add_action( ShowUrlAction(name, absname) )
+		self.add_action( CopyToClipboardAction(_("Location"), absname) )
 	
 	def get_hash(self, text=None):
 		return self.absname
@@ -58,15 +45,8 @@ class GtkBookmarkMatch(deskbar.interfaces.Match):
 	def __init__(self, name=None, path=None, **args):
 		deskbar.interfaces.Match.__init__(self, icon="gtk-open", name=name, category="places", **args)
 		self.path = path
-		
-	def action(self, text=None):
-		spawn_async(["nautilus", self.path])
-	
-	def is_valid(self, text=None):
-		return exists(self.path)
-	
-	def get_verb(self):
-		return _("Open location %s") % "<b>%(name)s</b>"
+		self.add_action( OpenWithNautilusAction(name, path) )
+		self.add_action( CopyToClipboardAction(_("Location"), path) )
 	
 	def get_hash(self, text=None):
 		return self.path
@@ -75,29 +55,9 @@ class VolumeMatch (deskbar.interfaces.Match):
 	def __init__(self, name=None, drive=None, icon=None, **args):
 		deskbar.interfaces.Match.__init__(self, name=name, category="places", icon=icon, **args)
 		self.drive = drive
-	
-	def action(self, text=None):
-		if self.drive == None:
-			spawn_async(["nautilus"])
-		else:
-			spawn_async(["nautilus", self.drive])
+		self.add_action( OpenWithNautilusAction(drive) )
+		self.add_action( CopyToClipboardAction(_("Location"), drive) )
 
-	def is_valid(self, text=None):
-		return exists(self.drive)
-	
-	def get_verb(self):
-		if self.drive == None:
-			uri_scheme = None
-		else:
-			uri_scheme = gnomevfs.get_uri_scheme(self.drive) 
-			
-		if uri_scheme in NETWORK_URIS:
-			return _("Open network place %s") % "<b>%(name)s</b>"
-		elif uri_scheme in AUDIO_URIS:
-			return _("Open audio disc %s") % "<b>%(name)s</b>"
-		else:
-			return _("Open location %s") % "<b>%(name)s</b>"
-	
 	def get_hash(self, text=None):
 		return self.drive
 		
@@ -134,7 +94,8 @@ class FileFolderHandler(deskbar.interfaces.Module):
 		query = query.lower()
 		for bmk, (name, loc) in self._locations.items():
 			if bmk.startswith(query):
-				result.append(GtkBookmarkMatch(name, loc, priority=self.get_priority()))
+				gtk_bookmark_match = GtkBookmarkMatch(name, loc, priority=self.get_priority())
+				result.append(gtk_bookmark_match)
 		
 		# Volumes		
 		# We search both mounted_volumes() and connected_drives.
@@ -147,7 +108,8 @@ class FileFolderHandler(deskbar.interfaces.Module):
 			if not drive.is_mounted () : continue
 			if not drive.get_display_name().lower().startswith(query): continue
 			
-			result.append (VolumeMatch (drive.get_display_name(), drive.get_activation_uri(), drive.get_icon(), priority=self.get_priority()))
+			vol_match = VolumeMatch (drive.get_display_name(), drive.get_activation_uri(), drive.get_icon(), priority=self.get_priority())
+			result.append (vol_match)
 		
 		self._emit_query_ready(query, result )
 	
