@@ -6,6 +6,9 @@ import deskbar.interfaces.Module
 import deskbar.interfaces.Match
 from deskbar.defs import VERSION
 from deskbar.core.Utils import spawn_async, url_show
+from deskbar.handlers.actions.OpenWithNautilusAction import OpenWithNautilusAction
+from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
+from deskbar.handlers.actions.SendEmailToAction import SendEmailToAction
 
 HANDLERS = ["WebAddressHandler"]
 
@@ -21,18 +24,11 @@ class WebAddressMatch(deskbar.interfaces.Match):
 		self.has_method = has_method
 		if not has_method and not self.url.startswith("http://"):
 			self.url = "http://" + url
-		
-	def action(self, text=None):
+			
 		if self.url.startswith("http"):
-			url_show(self.url)
+			self.add_action( ShowUrlAction(name, self.url) )
 		else:
-			spawn_async(["nautilus", self.url])
-	
-	def get_verb(self):
-		if not self.has_method:
-			return _("Open the web page %s") % "<b>%(name)s</b>"
-		else:
-			return _("Open the location %s") % "<b>%(name)s</b>"
+			self._add_action( OpenWithNautilusAction(name, self.url) )
 	
 	def get_hash(self, text=None):
 		return self.url
@@ -41,12 +37,7 @@ class EmailAddressMatch(deskbar.interfaces.Match):
 	def __init__(self, name=None, mail=None, **args):
 		deskbar.interfaces.Match.__init__(self, name=name, icon="stock_mail", category="people", **args)
 		self.mail = mail
-		
-	def action(self, text=None):
-		url_show("mailto:"+self.mail)
-	
-	def get_verb(self):
-		return _("Send Email to %s") % "<b>%(name)s</b>"
+		self.add_action( SendEmailToAction(name, mail) )
 	
 	def get_hash(self, text=None):
 		return self.mail
