@@ -3,7 +3,9 @@ from gettext import gettext as _
 from deskbar.defs import VERSION
 import urllib
 import gnomevfs
-import deskbar.interfaces.Module, deskbar.interfaces.Match, deskbar, deskbar.core.Utils
+import deskbar.interfaces.Module, deskbar.interfaces.Match, deskbar
+from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
+from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
 import xml.dom.minidom
 
 YAHOO_API_KEY = 'deskbar-applet'
@@ -13,17 +15,21 @@ QUERY_DELAY = 1
 
 HANDLERS = ["YahooHandler"]
 
-class YahooMatch(deskbar.interfaces.Match):
-	def __init__(self, url=None, **args):
-		deskbar.interfaces.Match.__init__ (self, category="web", icon="yahoo.png", **args)
-		self.url = url
+class OpenYahooAction(ShowUrlAction):
+	
+	def __init__(self, name, url):
+		ShowUrlAction.__init__(self, name, url)
 
 	def get_verb(self):
 		return "%(name)s"
 
-	def action(self, text=None):
-		deskbar.core.Utils.url_show(self.url)
-
+class YahooMatch(deskbar.interfaces.Match):
+	def __init__(self, url=None, **args):
+		deskbar.interfaces.Match.__init__ (self, category="web", icon="yahoo.png", **args)
+		self.url = url
+		self.add_action( OpenYahooAction(self.get_name(), self.url) )
+		self.add_action( CopyToClipboardAction( _("URL"), self.url) )
+	
 	def get_hash(self, text=None):
 		return self.url
 
